import { ContractTypeDefinitions, defineContractExport, defineContracts } from "@dunemask/vix/util";
import * as y from "yup";
import { DatabaseContract } from "./database.contracts";
// ====================================== Reused Contracts ======================================

const Project = y.object({
  id: y.string().required(),
  slug: y.string().required(),
  parentProject: y.string().required(),
  name: y.string().nullable(),
});

// ====================================== Response Contracts ======================================

export const ProjectContractRes = defineContractExport("CProjectContractRes", {
  CreateResponse: y
    .object({
      project: DatabaseContract.Project,
      user: DatabaseContract.User,
      publicKey: y.string().required(),
    })
    .required(),
  Project: Project.required(),
  ListProjects: y
    .object({
      project: Project.required(),
      childProjects: y.array(Project).required(),
    })
    .required(),
});

// ====================================== Request Contracts ======================================

export const ProjectContractReq = defineContractExport("CProjectContractReq", {
  ProjectParams: y.object({
    project: y.string().required(),
  }),
  Create: y.object({
    slug: y.string().required(),
    name: y.string().nullable(),
  }),
});

// ====================================== Combined Declarations ======================================

export const ProjectContract = defineContractExport("CProjectContract", { ...ProjectContractRes, ...ProjectContractReq });

// ====================================== Type Declarations ======================================

export type CProjectContractRes = ContractTypeDefinitions<typeof ProjectContractRes>;
export type CProjectContractReq = ContractTypeDefinitions<typeof ProjectContractReq>;
export type CProjectContract = ContractTypeDefinitions<typeof ProjectContract>;
